#!/bin/sh

config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/rc.d/rc.avahidaemon.new
config etc/rc.d/rc.avahidnsconfd.new

# If the avahi user/group don't exist, add them:
if grep "^avahi:x:" etc/passwd 1> /dev/null 2> /dev/null ; then
  true
else
  echo "avahi:x:86:86:avahi:/etc/avahi:" >> etc/passwd
fi
if grep "^avahi::" etc/group 1> /dev/null 2> /dev/null ; then
  true
else
  echo "avahi::86:avahi" >> etc/group
fi
if grep "^avahi:" etc/shadow 1> /dev/null 2> /dev/null ; then
  true
else
  echo "avahi:*:9797:0:::::" >> etc/shadow
fi

# if rc.local doesn't exist, create it
if [ ! -e etc/rc.d/rc.local ]; then
	echo "#!/bin/sh" > etc/rc.d/rc.local
	chmod 755 etc/rc.d/rc.local
fi
	
# if rc.avahi is executable, run it on startup
run=`grep ". /etc/rc.d/rc.avahidaemon" etc/rc.d/rc.local`
if [ "${run}" == "" ]; then	
cat << EOF >> etc/rc.d/rc.local

# To disable avahi, chmod rc.avahidaemon to 644
if [ -x /etc/rc.d/rc.avahidaemon -a -x /etc/rc.d/rc.avahidnsconfd ]; then
  echo "Starting the Avahi Zeroconf Subsystem"
  . /etc/rc.d/rc.avahidaemon start
  . /etc/rc.d/rc.avahidnsconfd start
fi
EOF
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

( cd usr/lib ; rm -rf libavahi-common.so.3 )
( cd usr/lib ; ln -sf libavahi-common.so.3.4.1 libavahi-common.so.3 )
( cd usr/lib ; rm -rf libavahi-common.so )
( cd usr/lib ; ln -sf libavahi-common.so.3.4.1 libavahi-common.so )
( cd usr/lib ; rm -rf libavahi-glib.so.1 )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so.1 )
( cd usr/lib ; rm -rf libavahi-glib.so )
( cd usr/lib ; ln -sf libavahi-glib.so.1.0.1 libavahi-glib.so )
( cd usr/lib ; rm -rf libavahi-core.so.4 )
( cd usr/lib ; ln -sf libavahi-core.so.4.0.3 libavahi-core.so.4 )
( cd usr/lib ; rm -rf libavahi-core.so )
( cd usr/lib ; ln -sf libavahi-core.so.4.0.3 libavahi-core.so )
( cd usr/lib ; rm -rf libavahi-client.so.3 )
( cd usr/lib ; ln -sf libavahi-client.so.3.1.3 libavahi-client.so.3 )
( cd usr/lib ; rm -rf libavahi-client.so )
( cd usr/lib ; ln -sf libavahi-client.so.3.1.3 libavahi-client.so )
( cd usr/lib ; rm -rf libdns_sd.so.1 )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so.1 )
( cd usr/lib ; rm -rf libdns_sd.so )
( cd usr/lib ; ln -sf libdns_sd.so.1.0.0 libdns_sd.so )
( cd usr/lib ; rm -rf libhowl.so.0 )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so.0 )
( cd usr/lib ; rm -rf libhowl.so )
( cd usr/lib ; ln -sf libhowl.so.0.0.0 libhowl.so )
( cd usr/bin ; rm -rf avahi-resolve-host-name )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-host-name )
( cd usr/bin ; rm -rf avahi-resolve-address )
( cd usr/bin ; ln -sf avahi-resolve avahi-resolve-address )
( cd usr/bin ; rm -rf avahi-browse-domains )
( cd usr/bin ; ln -sf avahi-browse avahi-browse-domains )
( cd usr/bin ; rm -rf avahi-publish-address )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-address )
( cd usr/bin ; rm -rf avahi-publish-service )
( cd usr/bin ; ln -sf avahi-publish avahi-publish-service )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-host-name.1 )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1 avahi-resolve-host-name.1 )
( cd usr/share/man/man1 ; rm -rf avahi-resolve-address.1 )
( cd usr/share/man/man1 ; ln -sf avahi-resolve.1 avahi-resolve-address.1 )
( cd usr/share/man/man1 ; rm -rf avahi-browse-domains.1 )
( cd usr/share/man/man1 ; ln -sf avahi-browse.1 avahi-browse-domains.1 )
( cd usr/share/man/man1 ; rm -rf avahi-publish-address.1 )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1 avahi-publish-address.1 )
( cd usr/share/man/man1 ; rm -rf avahi-publish-service.1 )
( cd usr/share/man/man1 ; ln -sf avahi-publish.1 avahi-publish-service.1 )
